# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/environment/clusters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import rollback_pb2 as prodvana_dot_common__config_dot_rollback__pb2
from prodvana.proto.prodvana.labels import labels_pb2 as prodvana_dot_labels_dot_labels__pb2
from prodvana.proto.prodvana.runtimes.extensions import fetch_pb2 as prodvana_dot_runtimes_dot_extensions_dot_fetch__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2
from prodvana.proto.prodvana.volumes import volumes_pb2 as prodvana_dot_volumes_dot_volumes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#prodvana/environment/clusters.proto\x12\x14prodvana.environment\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a prodvana/common_config/env.proto\x1a!prodvana/common_config/task.proto\x1a.prodvana/common_config/kubernetes_config.proto\x1a\'prodvana/common_config/parameters.proto\x1a$prodvana/common_config/program.proto\x1a%prodvana/common_config/rollback.proto\x1a\x1cprodvana/labels/labels.proto\x1a(prodvana/runtimes/extensions/fetch.proto\x1a\'prodvana/runtimes/runtimes_config.proto\x1a\x1eprodvana/volumes/volumes.proto\"\x95\x04\n\x0b\x43lusterAuth\x12\x38\n\x03\x65\x63s\x18\x05 \x01(\x0b\x32).prodvana.environment.ClusterAuth.ECSAuthH\x00\x12\x38\n\x03k8s\x18\x08 \x01(\x0b\x32).prodvana.environment.ClusterAuth.K8sAuthH\x00\x1ao\n\x07\x45\x43SAuth\x12\x12\n\naccess_key\x18\x01 \x01(\t\x12\x12\n\nsecret_key\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x17\n\x0f\x61ssume_role_arn\x18\x04 \x01(\t\x12\x13\n\x0b\x63luster_arn\x18\x05 \x01(\t\x1a\xa8\x01\n\x07K8sAuth\x12J\n\tagent_env\x18\x01 \x03(\x0b\x32\x37.prodvana.environment.ClusterAuth.K8sAuth.AgentEnvEntry\x12 \n\x18\x61gent_externally_managed\x18\x02 \x01(\x08\x1a/\n\rAgentEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nauth_oneofJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08R\textensionR\x08\x65ndpointR\x07\x63\x61_certR\x05tokenR\x0fservice_accountR\x0ek8s_agent_auth\"\x8e\x02\n\x07\x43luster\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12/\n\x04\x61uth\x18\x04 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x12/\n\x04type\x18\x05 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12\x33\n\x06\x63onfig\x18\x06 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12<\n\x18last_heartbeat_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x03\x10\x04R\x06origin\"\xc6\x01\n\x11\x46\x61keClusterConfig\x12Z\n\x11\x63rashing_programs\x18\x01 \x03(\x0b\x32?.prodvana.environment.FakeClusterConfig.CrashingProgramPatterns\x1aU\n\x17\x43rashingProgramPatterns\x12\x13\n\x0bimage_regex\x18\x01 \x01(\t\x12\x11\n\tcmd_regex\x18\x02 \x01(\t\x12\x12\n\nlog_output\x18\x03 \x01(\t\"\x9a\x01\n\x0bRetryPolicy\x12:\n\rbase_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x39\n\x0cmax_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x14\n\x0cmax_attempts\x18\x03 \x01(\x05\"\xfa\x04\n\x15\x45xtensionFetchCommand\x12\x39\n\x0btask_config\x18\x01 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x02 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x30\n\rpoll_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1asteady_state_poll_interval\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\x0cretry_policy\x18\x07 \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12j\n\x03\x65nv\x18\x05 \x03(\x0b\x32\x34.prodvana.environment.ExtensionFetchCommand.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12;\n\nfetch_mode\x18\x08 \x01(\x0e\x32\'.prodvana.runtimes.extensions.FetchMode\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01\"\x84\x04\n\x17\x45xtensionGetInfoCommand\x12\x39\n\x0btask_config\x18\x01 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x02 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x30\n\rpoll_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x37\n\x0cretry_policy\x18\x04 \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12l\n\x03\x65nv\x18\x05 \x03(\x0b\x32\x36.prodvana.environment.ExtensionGetInfoCommand.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12,\n$test_only_do_not_require_pvn_wrapper\x18\x06 \x01(\x08\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01\"\x8f\x04\n\x15\x45xtensionApplyCommand\x12\x39\n\x0btask_config\x18\x01 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x02 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12j\n\x03\x65nv\x18\x05 \x03(\x0b\x32\x34.prodvana.environment.ExtensionApplyCommand.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12\x37\n\x0cretry_policy\x18\x07 \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12\x1c\n\x14retryable_exit_codes\x18\x08 \x03(\x05\x12\x17\n\x0fmax_concurrency\x18\t \x01(\x05\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07\"\xd6\x04\n\x16\x45xtensionClusterConfig\x12\x44\n\x05\x61pply\x18\x01 \x01(\x0b\x32+.prodvana.environment.ExtensionApplyCommandB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12:\n\x05\x66\x65tch\x18\x02 \x01(\x0b\x32+.prodvana.environment.ExtensionFetchCommand\x12<\n\x05\x64\x65\x62ug\x18\x08 \x01(\x0b\x32-.prodvana.environment.ExtensionGetInfoCommand\x12?\n\x08get_info\x18\t \x01(\x0b\x32-.prodvana.environment.ExtensionGetInfoCommand\x12N\n\nparameters\x18\x03 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12J\n\rproxy_runtime\x18\x04 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x31\n\x04type\x18\x05 \x01(\x0e\x32#.prodvana.environment.ExtensionType\x12%\n\x1drequire_approval_before_apply\x18\x06 \x01(\x08\x12\x45\n\x18\x63onvergence_grace_period\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\"\xbc\x04\n\x18\x43ompiledExtensionCommand\x12\x13\n\x0bname_prefix\x18\x01 \x01(\t\x12\\\n\x07\x63ommand\x18\x02 \x01(\x0b\x32K.prodvana.environment.CompiledExtensionCommand.CompiledExtensionCommandExec\x12\x44\n\x11runtime_execution\x18\x03 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfig\x12\x44\n\x03\x65nv\x18\x04 \x03(\x0b\x32\x37.prodvana.environment.CompiledExtensionCommand.EnvEntry\x1a\xd2\x01\n\x1c\x43ompiledExtensionCommandExec\x12\x39\n\x0btask_config\x18\x01 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x02 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x42\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"(\n\x10IacRunnerCommand\x12\x14\n\x03\x63md\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x9c\x06\n\x15TerraformRunnerConfig\x12J\n\rproxy_runtime\x18\x01 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x41\n\x03\x65nv\x18\x02 \x03(\x0b\x32\x34.prodvana.environment.TerraformRunnerConfig.EnvEntry\x12)\n\x07volumes\x18\x03 \x03(\x0b\x32\x18.prodvana.volumes.Volume\x12\x37\n\x07pre_run\x18\x04 \x03(\x0b\x32&.prodvana.environment.IacRunnerCommand\x12\x30\n\rpoll_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1asteady_state_poll_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12%\n\x1drequire_approval_before_apply\x18\x06 \x01(\x08\x12\x45\n\x18\x63onvergence_grace_period\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12=\n\x12\x66\x65tch_retry_policy\x18\t \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12=\n\x12\x61pply_retry_policy\x18\n \x01(\x0b\x32!.prodvana.environment.RetryPolicy\x12\x1f\n\x17\x64isable_drift_detection\x18\x0b \x01(\x08\x12\x44\n\x0etask_resources\x18\x0c \x01(\x0b\x32,.prodvana.common_config.ResourceRequirements\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"Z\n\x12GKEClusterMetadata\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x18\n\x10\x63luster_location\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\"^\n\x0f\x43lusterMetadata\x12\x37\n\x03gke\x18\x01 \x01(\x0b\x32(.prodvana.environment.GKEClusterMetadataH\x00\x42\x12\n\x10\x63luster_metadata\"\xb7\x04\n\x0c\x41wsEcsConfig\x12J\n\rproxy_runtime\x18\x01 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12L\n\naccess_key\x18\x06 \x01(\x0b\x32,.prodvana.environment.AwsEcsConfig.AccessKeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12W\n\x1dinherit_role_from_runtime_env\x18\x07 \x01(\x0b\x32..prodvana.environment.AwsEcsConfig.InheritRoleH\x00\x12\x17\n\x06region\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x0b\x65\x63s_cluster\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x86\x01\n\tAccessKey\x12\"\n\x11\x61ws_access_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12U\n\x15\x61ws_secret_access_key\x18\x02 \x01(\x0b\x32,.prodvana.common_config.SecretReferenceValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a*\n\x0bInheritRole\x12\x1b\n\x13k8s_service_account\x18\x01 \x01(\tB\x12\n\x0b\x63redentials\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\x11\x61ws_access_key_idR\x15\x61ws_secret_access_key\"\x81\x02\n\x14GoogleCloudRunConfig\x12J\n\rproxy_runtime\x18\x01 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12V\n\x14service_account_json\x18\x02 \x01(\x0b\x32,.prodvana.common_config.SecretReferenceValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x18\n\x07project\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06region\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x12\n\x0b\x63redentials\x12\x03\xf8\x42\x01\"\x98\x11\n\rClusterConfig\x12\x0c\n\x04name\x18\x0e \x01(\t\x12>\n\x08kubecost\x18\x03 \x01(\x0b\x32,.prodvana.environment.ClusterConfig.Kubecost\x12<\n\x07\x64\x61tadog\x18\x04 \x01(\x0b\x32+.prodvana.environment.ClusterConfig.Datadog\x12\x43\n\x0b\x61lb_ingress\x18\x06 \x01(\x0b\x32..prodvana.environment.ClusterConfig.ALBIngress\x12G\n\rargo_rollouts\x18\x07 \x01(\x0b\x32\x30.prodvana.environment.ClusterConfig.ArgoRollouts\x12\x43\n\x0bgke_ingress\x18\x08 \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12P\n\x18self_managed_gke_ingress\x18\x0b \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12I\n\x0e\x63loud_provider\x18\t \x01(\x0e\x32\x31.prodvana.environment.ClusterConfig.CloudProvider\x12H\n\x19\x64\x65tected_cluster_metadata\x18\x12 \x01(\x0b\x32%.prodvana.environment.ClusterMetadata\x12M\n\x1euser_supplied_cluster_metadata\x18\x13 \x01(\x0b\x32%.prodvana.environment.ClusterMetadata\x12\x37\n\x04\x66\x61ke\x18\n \x01(\x0b\x32\'.prodvana.environment.FakeClusterConfigH\x00\x12\x41\n\textension\x18\x0c \x01(\x0b\x32,.prodvana.environment.ExtensionClusterConfigH\x00\x12>\n\x06\x63ustom\x18\x17 \x01(\x0b\x32,.prodvana.environment.ExtensionClusterConfigH\x00\x12G\n\x10terraform_runner\x18\x0f \x01(\x0b\x32+.prodvana.environment.TerraformRunnerConfigH\x00\x12\x44\n\rpulumi_runner\x18\x10 \x01(\x0b\x32+.prodvana.environment.TerraformRunnerConfigH\x00\x12\x35\n\x07\x61ws_ecs\x18\x14 \x01(\x0b\x32\".prodvana.environment.AwsEcsConfigH\x00\x12\x46\n\x10google_cloud_run\x18\x15 \x01(\x0b\x32*.prodvana.environment.GoogleCloudRunConfigH\x00\x12\x30\n\x06labels\x18\x11 \x03(\x0b\x32 .prodvana.labels.LabelDefinition\x12\x41\n\rauto_rollback\x18\x16 \x01(\x0b\x32*.prodvana.common_config.AutoRollbackConfig\x1aH\n\x08Kubecost\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1a\n\x12kubecost_namespace\x18\x03 \x01(\t\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x1a\x65\n\x07\x44\x61tadog\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x19\n\x11\x64\x61tadog_namespace\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x0c\n\x04site\x18\x05 \x01(\t\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x1a\x62\n\nALBIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1e\n\ringress_class\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12#\n\x1b\x64\x65\x66\x61ult_balancer_attributes\x18\x03 \x03(\t\x1a\xba\x03\n\x0c\x41rgoRollouts\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12T\n\ttemplates\x18\x02 \x03(\x0b\x32\x41.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate\x1a\xc2\x02\n\x10\x41nalysisTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x66\n\x0b\x61rg_mapping\x18\x02 \x03(\x0b\x32Q.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry\x1a}\n\x0f\x41rgMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12Y\n\x05value\x18\x02 \x01(\x0e\x32J.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue:\x02\x38\x01\"9\n\x08\x41rgValue\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVICE\x10\x01\x12\x13\n\x0fRELEASE_CHANNEL\x10\x02\x1a\x37\n\nGKEIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x18\n\x10\x63ontainer_native\x18\x02 \x01(\x08\"T\n\rCloudProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x45KS\x10\x01\x12\x07\n\x03GKE\x10\x02\x12\x07\n\x03\x41KS\x10\x03\x12\n\n\x06ONPREM\x10\x04\x12\x0f\n\x0bOTHER_CLOUD\x10\x05\x42\x0f\n\rcluster_oneofJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06R\x0f\x64isable_flaggerR\rdisable_istioR\x0f\x61ws_alb_ingress*\x91\x01\n\x0b\x43lusterType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03K8S\x10\x01\x12\x07\n\x03\x45\x43S\x10\x02\x12\x08\n\x04\x46\x41KE\x10\x03\x12\r\n\tEXTENSION\x10\x04\x12\x14\n\x10TERRAFORM_RUNNER\x10\x05\x12\x11\n\rPULUMI_RUNNER\x10\x06\x12\x0b\n\x07\x41WS_ECS\x10\x07\x12\x14\n\x10GOOGLE_CLOUD_RUN\x10\x08*n\n\rExtensionType\x12\x0b\n\x07GENERIC\x10\x00\x12\r\n\tTERRAFORM\x10\x01\x12\n\n\x06PULUMI\x10\x02\x12\x15\n\x11\x41WS_ECS_EXTENSION\x10\x03\x12\x1e\n\x1aGOOGLE_CLOUD_RUN_EXTENSION\x10\x04\x42PZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environmentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.environment.clusters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environment'
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._options = None
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_options = b'8\001'
  _RETRYPOLICY.fields_by_name['base_interval']._options = None
  _RETRYPOLICY.fields_by_name['base_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _RETRYPOLICY.fields_by_name['max_interval']._options = None
  _RETRYPOLICY.fields_by_name['max_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _EXTENSIONFETCHCOMMAND_ENVENTRY._options = None
  _EXTENSIONFETCHCOMMAND_ENVENTRY._serialized_options = b'8\001'
  _EXTENSIONFETCHCOMMAND.oneofs_by_name['exec_config']._options = None
  _EXTENSIONFETCHCOMMAND.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _EXTENSIONFETCHCOMMAND.fields_by_name['env']._options = None
  _EXTENSIONFETCHCOMMAND.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _EXTENSIONGETINFOCOMMAND_ENVENTRY._options = None
  _EXTENSIONGETINFOCOMMAND_ENVENTRY._serialized_options = b'8\001'
  _EXTENSIONGETINFOCOMMAND.oneofs_by_name['exec_config']._options = None
  _EXTENSIONGETINFOCOMMAND.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _EXTENSIONGETINFOCOMMAND.fields_by_name['env']._options = None
  _EXTENSIONGETINFOCOMMAND.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _EXTENSIONAPPLYCOMMAND_ENVENTRY._options = None
  _EXTENSIONAPPLYCOMMAND_ENVENTRY._serialized_options = b'8\001'
  _EXTENSIONAPPLYCOMMAND.oneofs_by_name['exec_config']._options = None
  _EXTENSIONAPPLYCOMMAND.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _EXTENSIONAPPLYCOMMAND.fields_by_name['env']._options = None
  _EXTENSIONAPPLYCOMMAND.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['apply']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['apply']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['parameters']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['proxy_runtime']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['proxy_runtime']._serialized_options = b'\372B\005\212\001\002\020\001'
  _EXTENSIONCLUSTERCONFIG.fields_by_name['convergence_grace_period']._options = None
  _EXTENSIONCLUSTERCONFIG.fields_by_name['convergence_grace_period']._serialized_options = b'\372B\005\252\001\002*\000'
  _COMPILEDEXTENSIONCOMMAND_COMPILEDEXTENSIONCOMMANDEXEC.oneofs_by_name['exec_config']._options = None
  _COMPILEDEXTENSIONCOMMAND_COMPILEDEXTENSIONCOMMANDEXEC.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._options = None
  _COMPILEDEXTENSIONCOMMAND_ENVENTRY._serialized_options = b'8\001'
  _IACRUNNERCOMMAND.fields_by_name['cmd']._options = None
  _IACRUNNERCOMMAND.fields_by_name['cmd']._serialized_options = b'\372B\004r\002\020\001'
  _TERRAFORMRUNNERCONFIG_ENVENTRY._options = None
  _TERRAFORMRUNNERCONFIG_ENVENTRY._serialized_options = b'8\001'
  _TERRAFORMRUNNERCONFIG.fields_by_name['proxy_runtime']._options = None
  _TERRAFORMRUNNERCONFIG.fields_by_name['proxy_runtime']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TERRAFORMRUNNERCONFIG.fields_by_name['convergence_grace_period']._options = None
  _TERRAFORMRUNNERCONFIG.fields_by_name['convergence_grace_period']._serialized_options = b'\372B\005\252\001\002*\000'
  _AWSECSCONFIG_ACCESSKEY.fields_by_name['aws_access_key_id']._options = None
  _AWSECSCONFIG_ACCESSKEY.fields_by_name['aws_access_key_id']._serialized_options = b'\372B\004r\002\020\001'
  _AWSECSCONFIG_ACCESSKEY.fields_by_name['aws_secret_access_key']._options = None
  _AWSECSCONFIG_ACCESSKEY.fields_by_name['aws_secret_access_key']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AWSECSCONFIG.oneofs_by_name['credentials']._options = None
  _AWSECSCONFIG.oneofs_by_name['credentials']._serialized_options = b'\370B\001'
  _AWSECSCONFIG.fields_by_name['proxy_runtime']._options = None
  _AWSECSCONFIG.fields_by_name['proxy_runtime']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AWSECSCONFIG.fields_by_name['access_key']._options = None
  _AWSECSCONFIG.fields_by_name['access_key']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AWSECSCONFIG.fields_by_name['region']._options = None
  _AWSECSCONFIG.fields_by_name['region']._serialized_options = b'\372B\004r\002\020\001'
  _AWSECSCONFIG.fields_by_name['ecs_cluster']._options = None
  _AWSECSCONFIG.fields_by_name['ecs_cluster']._serialized_options = b'\372B\004r\002\020\001'
  _GOOGLECLOUDRUNCONFIG.oneofs_by_name['credentials']._options = None
  _GOOGLECLOUDRUNCONFIG.oneofs_by_name['credentials']._serialized_options = b'\370B\001'
  _GOOGLECLOUDRUNCONFIG.fields_by_name['proxy_runtime']._options = None
  _GOOGLECLOUDRUNCONFIG.fields_by_name['proxy_runtime']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GOOGLECLOUDRUNCONFIG.fields_by_name['service_account_json']._options = None
  _GOOGLECLOUDRUNCONFIG.fields_by_name['service_account_json']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GOOGLECLOUDRUNCONFIG.fields_by_name['project']._options = None
  _GOOGLECLOUDRUNCONFIG.fields_by_name['project']._serialized_options = b'\372B\004r\002\020\001'
  _GOOGLECLOUDRUNCONFIG.fields_by_name['region']._options = None
  _GOOGLECLOUDRUNCONFIG.fields_by_name['region']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._options = None
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._options = None
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_options = b'8\001'
  _globals['_CLUSTERTYPE']._serialized_start=8623
  _globals['_CLUSTERTYPE']._serialized_end=8768
  _globals['_EXTENSIONTYPE']._serialized_start=8770
  _globals['_EXTENSIONTYPE']._serialized_end=8880
  _globals['_CLUSTERAUTH']._serialized_start=532
  _globals['_CLUSTERAUTH']._serialized_end=1065
  _globals['_CLUSTERAUTH_ECSAUTH']._serialized_start=663
  _globals['_CLUSTERAUTH_ECSAUTH']._serialized_end=774
  _globals['_CLUSTERAUTH_K8SAUTH']._serialized_start=777
  _globals['_CLUSTERAUTH_K8SAUTH']._serialized_end=945
  _globals['_CLUSTERAUTH_K8SAUTH_AGENTENVENTRY']._serialized_start=898
  _globals['_CLUSTERAUTH_K8SAUTH_AGENTENVENTRY']._serialized_end=945
  _globals['_CLUSTER']._serialized_start=1068
  _globals['_CLUSTER']._serialized_end=1338
  _globals['_FAKECLUSTERCONFIG']._serialized_start=1341
  _globals['_FAKECLUSTERCONFIG']._serialized_end=1539
  _globals['_FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS']._serialized_start=1454
  _globals['_FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS']._serialized_end=1539
  _globals['_RETRYPOLICY']._serialized_start=1542
  _globals['_RETRYPOLICY']._serialized_end=1696
  _globals['_EXTENSIONFETCHCOMMAND']._serialized_start=1699
  _globals['_EXTENSIONFETCHCOMMAND']._serialized_end=2333
  _globals['_EXTENSIONFETCHCOMMAND_ENVENTRY']._serialized_start=2237
  _globals['_EXTENSIONFETCHCOMMAND_ENVENTRY']._serialized_end=2313
  _globals['_EXTENSIONGETINFOCOMMAND']._serialized_start=2336
  _globals['_EXTENSIONGETINFOCOMMAND']._serialized_end=2852
  _globals['_EXTENSIONGETINFOCOMMAND_ENVENTRY']._serialized_start=2237
  _globals['_EXTENSIONGETINFOCOMMAND_ENVENTRY']._serialized_end=2313
  _globals['_EXTENSIONAPPLYCOMMAND']._serialized_start=2855
  _globals['_EXTENSIONAPPLYCOMMAND']._serialized_end=3382
  _globals['_EXTENSIONAPPLYCOMMAND_ENVENTRY']._serialized_start=2237
  _globals['_EXTENSIONAPPLYCOMMAND_ENVENTRY']._serialized_end=2313
  _globals['_EXTENSIONCLUSTERCONFIG']._serialized_start=3385
  _globals['_EXTENSIONCLUSTERCONFIG']._serialized_end=3983
  _globals['_COMPILEDEXTENSIONCOMMAND']._serialized_start=3986
  _globals['_COMPILEDEXTENSIONCOMMAND']._serialized_end=4558
  _globals['_COMPILEDEXTENSIONCOMMAND_COMPILEDEXTENSIONCOMMANDEXEC']._serialized_start=4270
  _globals['_COMPILEDEXTENSIONCOMMAND_COMPILEDEXTENSIONCOMMANDEXEC']._serialized_end=4480
  _globals['_COMPILEDEXTENSIONCOMMAND_ENVENTRY']._serialized_start=2237
  _globals['_COMPILEDEXTENSIONCOMMAND_ENVENTRY']._serialized_end=2313
  _globals['_IACRUNNERCOMMAND']._serialized_start=4560
  _globals['_IACRUNNERCOMMAND']._serialized_end=4600
  _globals['_TERRAFORMRUNNERCONFIG']._serialized_start=4603
  _globals['_TERRAFORMRUNNERCONFIG']._serialized_end=5399
  _globals['_TERRAFORMRUNNERCONFIG_ENVENTRY']._serialized_start=2237
  _globals['_TERRAFORMRUNNERCONFIG_ENVENTRY']._serialized_end=2313
  _globals['_GKECLUSTERMETADATA']._serialized_start=5401
  _globals['_GKECLUSTERMETADATA']._serialized_end=5491
  _globals['_CLUSTERMETADATA']._serialized_start=5493
  _globals['_CLUSTERMETADATA']._serialized_end=5587
  _globals['_AWSECSCONFIG']._serialized_start=5590
  _globals['_AWSECSCONFIG']._serialized_end=6157
  _globals['_AWSECSCONFIG_ACCESSKEY']._serialized_start=5905
  _globals['_AWSECSCONFIG_ACCESSKEY']._serialized_end=6039
  _globals['_AWSECSCONFIG_INHERITROLE']._serialized_start=6041
  _globals['_AWSECSCONFIG_INHERITROLE']._serialized_end=6083
  _globals['_GOOGLECLOUDRUNCONFIG']._serialized_start=6160
  _globals['_GOOGLECLOUDRUNCONFIG']._serialized_end=6417
  _globals['_CLUSTERCONFIG']._serialized_start=6420
  _globals['_CLUSTERCONFIG']._serialized_end=8620
  _globals['_CLUSTERCONFIG_KUBECOST']._serialized_start=7673
  _globals['_CLUSTERCONFIG_KUBECOST']._serialized_end=7745
  _globals['_CLUSTERCONFIG_DATADOG']._serialized_start=7747
  _globals['_CLUSTERCONFIG_DATADOG']._serialized_end=7848
  _globals['_CLUSTERCONFIG_ALBINGRESS']._serialized_start=7850
  _globals['_CLUSTERCONFIG_ALBINGRESS']._serialized_end=7948
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS']._serialized_start=7951
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS']._serialized_end=8393
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE']._serialized_start=8071
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE']._serialized_end=8393
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY']._serialized_start=8209
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY']._serialized_end=8334
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE']._serialized_start=8336
  _globals['_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE']._serialized_end=8393
  _globals['_CLUSTERCONFIG_GKEINGRESS']._serialized_start=8395
  _globals['_CLUSTERCONFIG_GKEINGRESS']._serialized_end=8450
  _globals['_CLUSTERCONFIG_CLOUDPROVIDER']._serialized_start=8452
  _globals['_CLUSTERCONFIG_CLOUDPROVIDER']._serialized_end=8536
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Notifications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ProgramFailures(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FAILURE_COUNT_FIELD_NUMBER: builtins.int
        MOST_RECENT_FAILURE_FIELD_NUMBER: builtins.int
        failure_count: builtins.int
        """Either k8s errors or runtime extension apply errors"""
        @property
        def most_recent_failure(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            failure_count: builtins.int = ...,
            most_recent_failure: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["most_recent_failure", b"most_recent_failure"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["failure_count", b"failure_count", "most_recent_failure", b"most_recent_failure"]) -> None: ...

    class RuntimeFailure(google.protobuf.message.Message):
        """Info to convey:
        - Extension Fetch couldn't be started - kubernetes errors?
        - Extension Fetch ran but failed
        - K8s apply error
        - Extension Apply couldn't be applied
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _FailureType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _FailureTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Notifications.RuntimeFailure._FailureType.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: Notifications.RuntimeFailure._FailureType.ValueType  # 0
            EXTENSION_FETCH_INVOKE_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 1
            EXTENSION_FETCH_RESULT_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 2
            RUNTIME_APPLY_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 3
            EXTENSION_APPLY_INVOKE_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 4

        class FailureType(_FailureType, metaclass=_FailureTypeEnumTypeWrapper): ...
        UNKNOWN: Notifications.RuntimeFailure.FailureType.ValueType  # 0
        EXTENSION_FETCH_INVOKE_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 1
        EXTENSION_FETCH_RESULT_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 2
        RUNTIME_APPLY_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 3
        EXTENSION_APPLY_INVOKE_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 4

        FAILURE_TYPE_FIELD_NUMBER: builtins.int
        MESSAGE_FIELD_NUMBER: builtins.int
        failure_type: global___Notifications.RuntimeFailure.FailureType.ValueType
        message: builtins.str
        """TODO: Indicate event id if possible"""
        def __init__(
            self,
            *,
            failure_type: global___Notifications.RuntimeFailure.FailureType.ValueType = ...,
            message: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["failure_type", b"failure_type", "message", b"message"]) -> None: ...

    class ProtectionFailure(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROTECTION_ID_FIELD_NUMBER: builtins.int
        @property
        def protection_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
        def __init__(
            self,
            *,
            protection_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["protection_id", b"protection_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["protection_id", b"protection_id"]) -> None: ...

    class ConvergenceExtensionFailure(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXTENSION_ID_FIELD_NUMBER: builtins.int
        @property
        def extension_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
        def __init__(
            self,
            *,
            extension_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["extension_id", b"extension_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["extension_id", b"extension_id"]) -> None: ...

    class DelayedConvergence(google.protobuf.message.Message):
        """- Runtime extension fetch has not completed a long time after it was started"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    PROGRAM_FAILURES_FIELD_NUMBER: builtins.int
    RUNTIME_FAILURES_FIELD_NUMBER: builtins.int
    PROTECTION_FAILURE_FIELD_NUMBER: builtins.int
    CONVERGENCE_EXTENSION_FAILURE_FIELD_NUMBER: builtins.int
    DELAYED_CONVERGENCE_FIELD_NUMBER: builtins.int
    CONCURRENCY_LIMIT_EXCEEDED_ERRORS_FIELD_NUMBER: builtins.int
    @property
    def program_failures(self) -> global___Notifications.ProgramFailures: ...
    @property
    def runtime_failures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Notifications.RuntimeFailure]: ...
    @property
    def protection_failure(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Notifications.ProtectionFailure]: ...
    @property
    def convergence_extension_failure(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Notifications.ConvergenceExtensionFailure]: ...
    @property
    def delayed_convergence(self) -> global___Notifications.DelayedConvergence: ...
    @property
    def concurrency_limit_exceeded_errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConcurrencyLimitExceeded]:
        """TODO: Link to next action?"""
    def __init__(
        self,
        *,
        program_failures: global___Notifications.ProgramFailures | None = ...,
        runtime_failures: collections.abc.Iterable[global___Notifications.RuntimeFailure] | None = ...,
        protection_failure: collections.abc.Iterable[global___Notifications.ProtectionFailure] | None = ...,
        convergence_extension_failure: collections.abc.Iterable[global___Notifications.ConvergenceExtensionFailure] | None = ...,
        delayed_convergence: global___Notifications.DelayedConvergence | None = ...,
        concurrency_limit_exceeded_errors: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConcurrencyLimitExceeded] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delayed_convergence", b"delayed_convergence", "program_failures", b"program_failures"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["concurrency_limit_exceeded_errors", b"concurrency_limit_exceeded_errors", "convergence_extension_failure", b"convergence_extension_failure", "delayed_convergence", b"delayed_convergence", "program_failures", b"program_failures", "protection_failure", b"protection_failure", "runtime_failures", b"runtime_failures"]) -> None: ...

global___Notifications = Notifications

class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SIMPLE_STATUS_FIELD_NUMBER: builtins.int
    STARTING_STATE_FIELD_NUMBER: builtins.int
    LAST_SEEN_STATE_FIELD_NUMBER: builtins.int
    DESIRED_STATE_FIELD_NUMBER: builtins.int
    TARGET_STATE_FIELD_NUMBER: builtins.int
    PRECONDITION_STATUSES_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    ACTION_EXPLANATION_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_FETCHED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_APPLIED_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    DIRECT_DEPENDENCIES_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    MISSING_APPROVAL_FIELD_NUMBER: builtins.int
    APPLY_ERROR_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def annotations(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations: ...
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType
    @property
    def starting_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def last_seen_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """the state we want to get to before calling convergence complete"""
    @property
    def target_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """the state we are actually going to apply. when preconditions are met, target state = desired state, otherwise, target state = previous desired state"""
    @property
    def precondition_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState]: ...
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog]: ...
    @property
    def action_explanation(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when the entity state last changed"""
    @property
    def last_fetched_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when prodvana last fetched entity state, best effort"""
    @property
    def last_applied_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when prodvana last applied state for this entity, best effort"""
    @property
    def dependencies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier]: ...
    @property
    def direct_dependencies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier]: ...
    lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType
    @property
    def missing_approval(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.MissingApproval: ...
    @property
    def apply_error(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ApplyError: ...
    @property
    def notifications(self) -> global___Notifications: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        annotations: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations | None = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType = ...,
        starting_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        last_seen_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        target_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        precondition_statuses: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState] | None = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
        logs: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog] | None = ...,
        action_explanation: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_fetched_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_applied_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dependencies: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier] | None = ...,
        direct_dependencies: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier] | None = ...,
        lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType = ...,
        missing_approval: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.MissingApproval | None = ...,
        apply_error: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ApplyError | None = ...,
        notifications: global___Notifications | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action_explanation", b"action_explanation", "annotations", b"annotations", "apply_error", b"apply_error", "desired_state", b"desired_state", "id", b"id", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "missing_approval", b"missing_approval", "notifications", b"notifications", "starting_state", b"starting_state", "target_state", b"target_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_explanation", b"action_explanation", "annotations", b"annotations", "apply_error", b"apply_error", "dependencies", b"dependencies", "desired_state", b"desired_state", "desired_state_id", b"desired_state_id", "direct_dependencies", b"direct_dependencies", "id", b"id", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "lifecycle", b"lifecycle", "logs", b"logs", "missing_approval", b"missing_approval", "notifications", b"notifications", "precondition_statuses", b"precondition_statuses", "root_desired_state_id", b"root_desired_state_id", "simple_status", b"simple_status", "starting_state", b"starting_state", "status", b"status", "status_explanations", b"status_explanations", "target_state", b"target_state"]) -> None: ...

global___Entity = Entity

class EntityGraph(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def root(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Entity]: ...
    def __init__(
        self,
        *,
        root: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        entities: collections.abc.Iterable[global___Entity] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["root", b"root"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities", "root", b"root"]) -> None: ...

global___EntityGraph = EntityGraph



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_extension/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.delivery_extension import object_pb2 as prodvana_dot_delivery__extension_dot_object__pb2
from prodvana.proto.prodvana.delivery_extension import config_pb2 as prodvana_dot_delivery__extension_dot_config__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/delivery_extension/manager.proto\x12\x1bprodvana.delivery_extension\x1a\x1cgoogle/api/annotations.proto\x1a(prodvana/delivery_extension/object.proto\x1a(prodvana/delivery_extension/config.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\xe7\x01\n\x1d\x43onfigureDeliveryExtensionReq\x12\x61\n\x19\x64\x65livery_extension_config\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x06source\x18\x02 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x03 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"P\n\x1e\x43onfigureDeliveryExtensionResp\x12\x1d\n\x15\x64\x65livery_extension_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xc3\x01\n&ValidateConfigureDeliveryExtensionResp\x12J\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12M\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\"B\n\x19ListDeliveryExtensionsReq\x12\x12\n\npage_token\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\"\x82\x01\n\x1aListDeliveryExtensionsResp\x12K\n\x13\x64\x65livery_extensions\x18\x01 \x03(\x0b\x32..prodvana.delivery_extension.DeliveryExtension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\">\n\x17GetDeliveryExtensionReq\x12#\n\x12\x64\x65livery_extension\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"f\n\x18GetDeliveryExtensionResp\x12J\n\x12\x64\x65livery_extension\x18\x01 \x01(\x0b\x32..prodvana.delivery_extension.DeliveryExtension\"U\n\x1dGetDeliveryExtensionConfigReq\x12#\n\x12\x64\x65livery_extension\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xcc\x01\n\x1eGetDeliveryExtensionConfigResp\x12J\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12M\n\x0f\x63ompiled_config\x18\x03 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\"i\n%GetDeliveryExtensionInstanceConfigReq\x12/\n\x1e\x64\x65livery_extension_instance_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x8f\x01\n&GetDeliveryExtensionInstanceConfigResp\x12T\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x44.prodvana.delivery_extension.CompiledDeliveryExtensionInstanceConfig\x12\x0f\n\x07version\x18\x02 \x01(\t2\x82\n\n\x18\x44\x65liveryExtensionManager\x12\xc3\x01\n\x1a\x43onfigureDeliveryExtension\x12:.prodvana.delivery_extension.ConfigureDeliveryExtensionReq\x1a;.prodvana.delivery_extension.ConfigureDeliveryExtensionResp\",\x82\xd3\xe4\x93\x02&\"!/v1/delivery_extensions/configure:\x01*\x12\xdc\x01\n\"ValidateConfigureDeliveryExtension\x12:.prodvana.delivery_extension.ConfigureDeliveryExtensionReq\x1a\x43.prodvana.delivery_extension.ValidateConfigureDeliveryExtensionResp\"5\x82\xd3\xe4\x93\x02/\"*/v1/delivery_extensions/configure/validate:\x01*\x12\xaa\x01\n\x16ListDeliveryExtensions\x12\x36.prodvana.delivery_extension.ListDeliveryExtensionsReq\x1a\x37.prodvana.delivery_extension.ListDeliveryExtensionsResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/delivery_extensions\x12\xba\x01\n\x14GetDeliveryExtension\x12\x34.prodvana.delivery_extension.GetDeliveryExtensionReq\x1a\x35.prodvana.delivery_extension.GetDeliveryExtensionResp\"5\x82\xd3\xe4\x93\x02/\x12-/v1/delivery_extension/{delivery_extension=*}\x12\xd3\x01\n\x1aGetDeliveryExtensionConfig\x12:.prodvana.delivery_extension.GetDeliveryExtensionConfigReq\x1a;.prodvana.delivery_extension.GetDeliveryExtensionConfigResp\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/v1/delivery_extension/{delivery_extension=*}/config\x12\x80\x02\n\"GetDeliveryExtensionInstanceConfig\x12\x42.prodvana.delivery_extension.GetDeliveryExtensionInstanceConfigReq\x1a\x43.prodvana.delivery_extension.GetDeliveryExtensionInstanceConfigResp\"Q\x82\xd3\xe4\x93\x02K\x12I/v1/delivery_extension/instance/{delivery_extension_instance_id=*}/configBWZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.delivery_extension.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extension'
  _CONFIGUREDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension_config']._options = None
  _CONFIGUREDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension']._options = None
  _GETDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension']._serialized_options = b'\372B\004r\002\020\001'
  _GETDELIVERYEXTENSIONCONFIGREQ.fields_by_name['delivery_extension']._options = None
  _GETDELIVERYEXTENSIONCONFIGREQ.fields_by_name['delivery_extension']._serialized_options = b'\372B\004r\002\020\001'
  _GETDELIVERYEXTENSIONINSTANCECONFIGREQ.fields_by_name['delivery_extension_instance_id']._options = None
  _GETDELIVERYEXTENSIONINSTANCECONFIGREQ.fields_by_name['delivery_extension_instance_id']._serialized_options = b'\372B\004r\002\020\001'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ConfigureDeliveryExtension']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ConfigureDeliveryExtension']._serialized_options = b'\202\323\344\223\002&\"!/v1/delivery_extensions/configure:\001*'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ValidateConfigureDeliveryExtension']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ValidateConfigureDeliveryExtension']._serialized_options = b'\202\323\344\223\002/\"*/v1/delivery_extensions/configure/validate:\001*'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ListDeliveryExtensions']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ListDeliveryExtensions']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/delivery_extensions'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtension']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtension']._serialized_options = b'\202\323\344\223\002/\022-/v1/delivery_extension/{delivery_extension=*}'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionConfig']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionConfig']._serialized_options = b'\202\323\344\223\0026\0224/v1/delivery_extension/{delivery_extension=*}/config'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionInstanceConfig']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionInstanceConfig']._serialized_options = b'\202\323\344\223\002K\022I/v1/delivery_extension/instance/{delivery_extension_instance_id=*}/config'
  _globals['_CONFIGUREDELIVERYEXTENSIONREQ']._serialized_start=254
  _globals['_CONFIGUREDELIVERYEXTENSIONREQ']._serialized_end=485
  _globals['_CONFIGUREDELIVERYEXTENSIONRESP']._serialized_start=487
  _globals['_CONFIGUREDELIVERYEXTENSIONRESP']._serialized_end=567
  _globals['_VALIDATECONFIGUREDELIVERYEXTENSIONRESP']._serialized_start=570
  _globals['_VALIDATECONFIGUREDELIVERYEXTENSIONRESP']._serialized_end=765
  _globals['_LISTDELIVERYEXTENSIONSREQ']._serialized_start=767
  _globals['_LISTDELIVERYEXTENSIONSREQ']._serialized_end=833
  _globals['_LISTDELIVERYEXTENSIONSRESP']._serialized_start=836
  _globals['_LISTDELIVERYEXTENSIONSRESP']._serialized_end=966
  _globals['_GETDELIVERYEXTENSIONREQ']._serialized_start=968
  _globals['_GETDELIVERYEXTENSIONREQ']._serialized_end=1030
  _globals['_GETDELIVERYEXTENSIONRESP']._serialized_start=1032
  _globals['_GETDELIVERYEXTENSIONRESP']._serialized_end=1134
  _globals['_GETDELIVERYEXTENSIONCONFIGREQ']._serialized_start=1136
  _globals['_GETDELIVERYEXTENSIONCONFIGREQ']._serialized_end=1221
  _globals['_GETDELIVERYEXTENSIONCONFIGRESP']._serialized_start=1224
  _globals['_GETDELIVERYEXTENSIONCONFIGRESP']._serialized_end=1428
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGREQ']._serialized_start=1430
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGREQ']._serialized_end=1535
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGRESP']._serialized_start=1538
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGRESP']._serialized_end=1681
  _globals['_DELIVERYEXTENSIONMANAGER']._serialized_start=1684
  _globals['_DELIVERYEXTENSIONMANAGER']._serialized_end=2966
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/stat/efficiency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/stat/efficiency.proto\x12\rprodvana.stat\"A\n\x0e\x45\x66\x66iciencyStat\x12\x13\n\x0bsaved_lines\x18\x01 \x01(\x05\x12\x1a\n\x12materialized_lines\x18\x02 \x01(\x05\x42IZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/statb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.stat.efficiency_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZGgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/stat'
  _globals['_EFFICIENCYSTAT']._serialized_start=49
  _globals['_EFFICIENCYSTAT']._serialized_end=114
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/settings/organization/roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*prodvana/settings/organization/roles.proto\x12\x1eprodvana.settings.organization*V\n\x04Role\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tORG_ADMIN\x10\x01\x12\x0f\n\x0b\x43LOUD_ADMIN\x10\x02\x12\x11\n\rSERVICE_OWNER\x10\x03\x12\n\n\x06VIEWER\x10\x04\x42ZZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.settings.organization.roles_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organization'
  _globals['_ROLE']._serialized_start=78
  _globals['_ROLE']._serialized_end=164
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.agent import agent_interaction_pb2 as prodvana_dot_agent_dot_agent__interaction__pb2


class AgentInteractionStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Heartbeat = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/Heartbeat',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.HeartbeatReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.HeartbeatResp.FromString,
                )
        self.ConfirmPushApproval = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/ConfirmPushApproval',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ConfirmPushApprovalReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ConfirmPushApprovalResp.FromString,
                )
        self.RecordNewUnknownPush = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordNewUnknownPush',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordNewUnknownPushReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordNewUnknownPushResp.FromString,
                )
        self.RecordPushStart = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordPushStart',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushStartReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushStartResp.FromString,
                )
        self.RecordPushOngoing = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordPushOngoing',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushOngoingReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushOngoingResp.FromString,
                )
        self.RecordPushComplete = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordPushComplete',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushCompleteReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushCompleteResp.FromString,
                )
        self.RecordPod = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordPod',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodResp.FromString,
                )
        self.RecordPods = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordPods',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodsReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodsResp.FromString,
                )
        self.RecordDeployment = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordDeployment',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordDeploymentReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordDeploymentResp.FromString,
                )
        self.RecordRollout = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/RecordRollout',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordRolloutReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordRolloutResp.FromString,
                )
        self.ProxyAPIServer = channel.stream_stream(
                '/prodvana.agent.AgentInteraction/ProxyAPIServer',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ProxyAPIServerReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ProxyAPIServerResp.FromString,
                )
        self.ReportDebugInfo = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/ReportDebugInfo',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportDebugInfoReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportDebugInfoResp.FromString,
                )
        self.ReportClusterMetadata = channel.unary_unary(
                '/prodvana.agent.AgentInteraction/ReportClusterMetadata',
                request_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportClusterMetadataReq.SerializeToString,
                response_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportClusterMetadataResp.FromString,
                )


class AgentInteractionServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Heartbeat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfirmPushApproval(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordNewUnknownPush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordPushStart(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordPushOngoing(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordPushComplete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordPod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordPods(self, request, context):
        """Dump a snapshot of all pods for a service. Can potentially contain multiple services, or all services.
        Guaranteed to contain all pods for one service.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecordRollout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProxyAPIServer(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportDebugInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportClusterMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentInteractionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Heartbeat': grpc.unary_unary_rpc_method_handler(
                    servicer.Heartbeat,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.HeartbeatReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.HeartbeatResp.SerializeToString,
            ),
            'ConfirmPushApproval': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfirmPushApproval,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ConfirmPushApprovalReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ConfirmPushApprovalResp.SerializeToString,
            ),
            'RecordNewUnknownPush': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordNewUnknownPush,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordNewUnknownPushReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordNewUnknownPushResp.SerializeToString,
            ),
            'RecordPushStart': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordPushStart,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushStartReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushStartResp.SerializeToString,
            ),
            'RecordPushOngoing': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordPushOngoing,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushOngoingReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushOngoingResp.SerializeToString,
            ),
            'RecordPushComplete': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordPushComplete,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushCompleteReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushCompleteResp.SerializeToString,
            ),
            'RecordPod': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordPod,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodResp.SerializeToString,
            ),
            'RecordPods': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordPods,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodsReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodsResp.SerializeToString,
            ),
            'RecordDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordDeployment,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordDeploymentReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordDeploymentResp.SerializeToString,
            ),
            'RecordRollout': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordRollout,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordRolloutReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.RecordRolloutResp.SerializeToString,
            ),
            'ProxyAPIServer': grpc.stream_stream_rpc_method_handler(
                    servicer.ProxyAPIServer,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ProxyAPIServerReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ProxyAPIServerResp.SerializeToString,
            ),
            'ReportDebugInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportDebugInfo,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportDebugInfoReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportDebugInfoResp.SerializeToString,
            ),
            'ReportClusterMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportClusterMetadata,
                    request_deserializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportClusterMetadataReq.FromString,
                    response_serializer=prodvana_dot_agent_dot_agent__interaction__pb2.ReportClusterMetadataResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.agent.AgentInteraction', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AgentInteraction(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Heartbeat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/Heartbeat',
            prodvana_dot_agent_dot_agent__interaction__pb2.HeartbeatReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.HeartbeatResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfirmPushApproval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/ConfirmPushApproval',
            prodvana_dot_agent_dot_agent__interaction__pb2.ConfirmPushApprovalReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.ConfirmPushApprovalResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordNewUnknownPush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordNewUnknownPush',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordNewUnknownPushReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordNewUnknownPushResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordPushStart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordPushStart',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushStartReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushStartResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordPushOngoing(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordPushOngoing',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushOngoingReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushOngoingResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordPushComplete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordPushComplete',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushCompleteReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPushCompleteResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordPod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordPod',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordPods(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordPods',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodsReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordPodsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordDeployment',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordDeploymentReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordDeploymentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecordRollout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/RecordRollout',
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordRolloutReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.RecordRolloutResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProxyAPIServer(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/prodvana.agent.AgentInteraction/ProxyAPIServer',
            prodvana_dot_agent_dot_agent__interaction__pb2.ProxyAPIServerReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.ProxyAPIServerResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportDebugInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/ReportDebugInfo',
            prodvana_dot_agent_dot_agent__interaction__pb2.ReportDebugInfoReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.ReportDebugInfoResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportClusterMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.agent.AgentInteraction/ReportClusterMetadata',
            prodvana_dot_agent_dot_agent__interaction__pb2.ReportClusterMetadataReq.SerializeToString,
            prodvana_dot_agent_dot_agent__interaction__pb2.ReportClusterMetadataResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.protection import protection_manager_pb2 as prodvana_dot_protection_dot_protection__manager__pb2


class ProtectionManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureProtection = channel.unary_unary(
                '/prodvana.protection.ProtectionManager/ConfigureProtection',
                request_serializer=prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionReq.SerializeToString,
                response_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionResp.FromString,
                )
        self.ValidateConfigureProtection = channel.unary_unary(
                '/prodvana.protection.ProtectionManager/ValidateConfigureProtection',
                request_serializer=prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionReq.SerializeToString,
                response_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.ValidateConfigureProtectionResp.FromString,
                )
        self.ListProtections = channel.unary_unary(
                '/prodvana.protection.ProtectionManager/ListProtections',
                request_serializer=prodvana_dot_protection_dot_protection__manager__pb2.ListProtectionsReq.SerializeToString,
                response_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.ListProtectionsResp.FromString,
                )
        self.GetProtection = channel.unary_unary(
                '/prodvana.protection.ProtectionManager/GetProtection',
                request_serializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionReq.SerializeToString,
                response_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionResp.FromString,
                )
        self.GetProtectionConfig = channel.unary_unary(
                '/prodvana.protection.ProtectionManager/GetProtectionConfig',
                request_serializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionConfigResp.FromString,
                )
        self.GetProtectionAttachmentConfig = channel.unary_unary(
                '/prodvana.protection.ProtectionManager/GetProtectionAttachmentConfig',
                request_serializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionAttachmentConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionAttachmentConfigResp.FromString,
                )


class ProtectionManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureProtection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureProtection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProtections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProtection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProtectionConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProtectionAttachmentConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProtectionManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureProtection': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureProtection,
                    request_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionReq.FromString,
                    response_serializer=prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionResp.SerializeToString,
            ),
            'ValidateConfigureProtection': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureProtection,
                    request_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionReq.FromString,
                    response_serializer=prodvana_dot_protection_dot_protection__manager__pb2.ValidateConfigureProtectionResp.SerializeToString,
            ),
            'ListProtections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProtections,
                    request_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.ListProtectionsReq.FromString,
                    response_serializer=prodvana_dot_protection_dot_protection__manager__pb2.ListProtectionsResp.SerializeToString,
            ),
            'GetProtection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProtection,
                    request_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionReq.FromString,
                    response_serializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionResp.SerializeToString,
            ),
            'GetProtectionConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProtectionConfig,
                    request_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionConfigReq.FromString,
                    response_serializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionConfigResp.SerializeToString,
            ),
            'GetProtectionAttachmentConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProtectionAttachmentConfig,
                    request_deserializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionAttachmentConfigReq.FromString,
                    response_serializer=prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionAttachmentConfigResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.protection.ProtectionManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProtectionManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureProtection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.protection.ProtectionManager/ConfigureProtection',
            prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionReq.SerializeToString,
            prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureProtection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.protection.ProtectionManager/ValidateConfigureProtection',
            prodvana_dot_protection_dot_protection__manager__pb2.ConfigureProtectionReq.SerializeToString,
            prodvana_dot_protection_dot_protection__manager__pb2.ValidateConfigureProtectionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProtections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.protection.ProtectionManager/ListProtections',
            prodvana_dot_protection_dot_protection__manager__pb2.ListProtectionsReq.SerializeToString,
            prodvana_dot_protection_dot_protection__manager__pb2.ListProtectionsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProtection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.protection.ProtectionManager/GetProtection',
            prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionReq.SerializeToString,
            prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProtectionConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.protection.ProtectionManager/GetProtectionConfig',
            prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionConfigReq.SerializeToString,
            prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProtectionAttachmentConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.protection.ProtectionManager/GetProtectionAttachmentConfig',
            prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionAttachmentConfigReq.SerializeToString,
            prodvana_dot_protection_dot_protection__manager__pb2.GetProtectionAttachmentConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DeploymentMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Deltas(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOTAL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_PER_DAY_FIELD_NUMBER: builtins.int
        FAILED_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_DEPLOYMENT_DURATION_FIELD_NUMBER: builtins.int
        DEPLOYMENT_FAILURE_RATE_FIELD_NUMBER: builtins.int
        TOTAL_ROLLBACKS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_ROLLBACKS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_ROLLBACK_DURATION_FIELD_NUMBER: builtins.int
        total_deployments: builtins.float
        successful_deployments: builtins.float
        successful_deployments_per_day: builtins.float
        failed_deployments: builtins.float
        median_successful_deployment_duration: builtins.float
        deployment_failure_rate: builtins.float
        total_rollbacks: builtins.float
        successful_rollbacks: builtins.float
        median_successful_rollback_duration: builtins.float
        def __init__(
            self,
            *,
            total_deployments: builtins.float = ...,
            successful_deployments: builtins.float = ...,
            successful_deployments_per_day: builtins.float = ...,
            failed_deployments: builtins.float = ...,
            median_successful_deployment_duration: builtins.float = ...,
            deployment_failure_rate: builtins.float = ...,
            total_rollbacks: builtins.float = ...,
            successful_rollbacks: builtins.float = ...,
            median_successful_rollback_duration: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["deployment_failure_rate", b"deployment_failure_rate", "failed_deployments", b"failed_deployments", "median_successful_deployment_duration", b"median_successful_deployment_duration", "median_successful_rollback_duration", b"median_successful_rollback_duration", "successful_deployments", b"successful_deployments", "successful_deployments_per_day", b"successful_deployments_per_day", "successful_rollbacks", b"successful_rollbacks", "total_deployments", b"total_deployments", "total_rollbacks", b"total_rollbacks"]) -> None: ...

    class Values(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOTAL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_PER_DAY_FIELD_NUMBER: builtins.int
        FAILED_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_DEPLOYMENT_DURATION_FIELD_NUMBER: builtins.int
        DEPLOYMENT_FAILURE_RATE_FIELD_NUMBER: builtins.int
        TOTAL_ROLLBACKS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_ROLLBACKS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_ROLLBACK_DURATION_FIELD_NUMBER: builtins.int
        LAST_SUCCESSFUL_DEPLOYMENT_COMPLETION_TIME_FIELD_NUMBER: builtins.int
        total_deployments: builtins.float
        successful_deployments: builtins.float
        successful_deployments_per_day: builtins.float
        failed_deployments: builtins.float
        @property
        def median_successful_deployment_duration(self) -> google.protobuf.duration_pb2.Duration: ...
        deployment_failure_rate: builtins.float
        total_rollbacks: builtins.float
        successful_rollbacks: builtins.float
        @property
        def median_successful_rollback_duration(self) -> google.protobuf.duration_pb2.Duration: ...
        @property
        def last_successful_deployment_completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            total_deployments: builtins.float = ...,
            successful_deployments: builtins.float = ...,
            successful_deployments_per_day: builtins.float = ...,
            failed_deployments: builtins.float = ...,
            median_successful_deployment_duration: google.protobuf.duration_pb2.Duration | None = ...,
            deployment_failure_rate: builtins.float = ...,
            total_rollbacks: builtins.float = ...,
            successful_rollbacks: builtins.float = ...,
            median_successful_rollback_duration: google.protobuf.duration_pb2.Duration | None = ...,
            last_successful_deployment_completion_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["last_successful_deployment_completion_time", b"last_successful_deployment_completion_time", "median_successful_deployment_duration", b"median_successful_deployment_duration", "median_successful_rollback_duration", b"median_successful_rollback_duration"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["deployment_failure_rate", b"deployment_failure_rate", "failed_deployments", b"failed_deployments", "last_successful_deployment_completion_time", b"last_successful_deployment_completion_time", "median_successful_deployment_duration", b"median_successful_deployment_duration", "median_successful_rollback_duration", b"median_successful_rollback_duration", "successful_deployments", b"successful_deployments", "successful_deployments_per_day", b"successful_deployments_per_day", "successful_rollbacks", b"successful_rollbacks", "total_deployments", b"total_deployments", "total_rollbacks", b"total_rollbacks"]) -> None: ...

    class TimeseriesMetrics(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        FAILED_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        @property
        def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        successful_deployments: builtins.float
        failed_deployments: builtins.float
        def __init__(
            self,
            *,
            timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            successful_deployments: builtins.float = ...,
            failed_deployments: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["failed_deployments", b"failed_deployments", "successful_deployments", b"successful_deployments", "timestamp", b"timestamp"]) -> None: ...

    VALUES_FIELD_NUMBER: builtins.int
    TIMESERIES_FIELD_NUMBER: builtins.int
    DELTAS_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> global___DeploymentMetrics.Values: ...
    @property
    def timeseries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentMetrics.TimeseriesMetrics]: ...
    @property
    def deltas(self) -> global___DeploymentMetrics.Deltas: ...
    def __init__(
        self,
        *,
        values: global___DeploymentMetrics.Values | None = ...,
        timeseries: collections.abc.Iterable[global___DeploymentMetrics.TimeseriesMetrics] | None = ...,
        deltas: global___DeploymentMetrics.Deltas | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deltas", b"deltas", "values", b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deltas", b"deltas", "timeseries", b"timeseries", "values", b"values"]) -> None: ...

global___DeploymentMetrics = DeploymentMetrics

class Cost(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURED_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    configured: builtins.bool
    cost: builtins.float
    def __init__(
        self,
        *,
        configured: builtins.bool = ...,
        cost: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["configured", b"configured", "cost", b"cost"]) -> None: ...

global___Cost = Cost



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/impact_analysis/impact_analysis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/impact_analysis/impact_analysis.proto\x12\x18prodvana.impact_analysis\"\x90\x02\n\x14ImpactAnalysisResult\x12:\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32(.prodvana.impact_analysis.ImpactCategory\x12=\n\rincident_type\x18\x02 \x01(\x0e\x32&.prodvana.impact_analysis.IncidentType\x12\x14\n\x0cimpact_score\x18\x03 \x01(\x01\x12\x18\n\x10impact_reasoning\x18\x04 \x01(\t\x12\x18\n\x10likelihood_score\x18\x05 \x01(\x01\x12\x1c\n\x14likelihood_reasoning\x18\x06 \x01(\t\x12\x15\n\roverall_score\x18\x07 \x01(\x01*\x8a\x01\n\x0eImpactCategory\x12\x14\n\x10UNKNOWN_CATEGORY\x10\x00\x12\x0b\n\x07\x42\x41\x43KEND\x10\x01\x12\x0c\n\x08\x46RONTEND\x10\x02\x12\x12\n\x0e\x44\x41TA_INTEGRITY\x10\x03\x12\x0c\n\x08SECURITY\x10\x04\x12\x08\n\x04\x43OST\x10\x05\x12\x1b\n\x17PRODVANA_INTERNAL_ERROR\x10\x06*b\n\x0cIncidentType\x12\x14\n\x10UNKNOWN_INCIDENT\x10\x00\x12\n\n\x06OUTAGE\x10\x01\x12\x0b\n\x07\x45XPENSE\x10\x02\x12\x13\n\x0fSECURITY_BREACH\x10\x03\x12\x0e\n\nUSER_ISSUE\x10\x04\x42TZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/impact_analysisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.impact_analysis.impact_analysis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/impact_analysis'
  _globals['_IMPACTCATEGORY']._serialized_start=352
  _globals['_IMPACTCATEGORY']._serialized_end=490
  _globals['_INCIDENTTYPE']._serialized_start=492
  _globals['_INCIDENTTYPE']._serialized_end=590
  _globals['_IMPACTANALYSISRESULT']._serialized_start=77
  _globals['_IMPACTANALYSISRESULT']._serialized_end=349
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class VolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class SecretSource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SECRET_NAME_FIELD_NUMBER: builtins.int
        secret_name: builtins.str
        def __init__(
            self,
            *,
            secret_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["secret_name", b"secret_name"]) -> None: ...

    class EphemeralSource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Medium:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _MediumEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VolumeSource.EphemeralSource._Medium.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: VolumeSource.EphemeralSource._Medium.ValueType  # 0
            DEFAULT: VolumeSource.EphemeralSource._Medium.ValueType  # 1
            """for kubernetes, this the the node's default storage medium"""
            MEMORY: VolumeSource.EphemeralSource._Medium.ValueType  # 2

        class Medium(_Medium, metaclass=_MediumEnumTypeWrapper): ...
        UNKNOWN: VolumeSource.EphemeralSource.Medium.ValueType  # 0
        DEFAULT: VolumeSource.EphemeralSource.Medium.ValueType  # 1
        """for kubernetes, this the the node's default storage medium"""
        MEMORY: VolumeSource.EphemeralSource.Medium.ValueType  # 2

        MEDIUM_FIELD_NUMBER: builtins.int
        medium: global___VolumeSource.EphemeralSource.Medium.ValueType
        def __init__(
            self,
            *,
            medium: global___VolumeSource.EphemeralSource.Medium.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["medium", b"medium"]) -> None: ...

    SECRET_FIELD_NUMBER: builtins.int
    EPHEMERAL_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> global___VolumeSource.SecretSource: ...
    @property
    def ephemeral(self) -> global___VolumeSource.EphemeralSource: ...
    def __init__(
        self,
        *,
        secret: global___VolumeSource.SecretSource | None = ...,
        ephemeral: global___VolumeSource.EphemeralSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ephemeral", b"ephemeral", "secret", b"secret", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ephemeral", b"ephemeral", "secret", b"secret", "source", b"source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["source", b"source"]) -> typing_extensions.Literal["secret", "ephemeral"] | None: ...

global___VolumeSource = VolumeSource

class VolumeMount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOUNT_PATH_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    mount_path: builtins.str
    read_only: builtins.bool
    def __init__(
        self,
        *,
        mount_path: builtins.str = ...,
        read_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount_path", b"mount_path", "read_only", b"read_only"]) -> None: ...

global___VolumeMount = VolumeMount

class Volume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    MOUNT_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def source(self) -> global___VolumeSource: ...
    @property
    def mount(self) -> global___VolumeMount: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        source: global___VolumeSource | None = ...,
        mount: global___VolumeMount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mount", b"mount", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount", b"mount", "name", b"name", "source", b"source"]) -> None: ...

global___Volume = Volume



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.impact_analysis.impact_analysis_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    name: builtins.str
    email: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "name", b"name"]) -> None: ...

global___User = User

class Commit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMIT_ID_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    IMPACT_ANALYSIS_FIELD_NUMBER: builtins.int
    COMMIT_TIMESTAMP_FIELD_NUMBER: builtins.int
    commit_id: builtins.str
    url: builtins.str
    message: builtins.str
    @property
    def author(self) -> global___User: ...
    @property
    def impact_analysis(self) -> prodvana.proto.prodvana.impact_analysis.impact_analysis_pb2.ImpactAnalysisResult: ...
    @property
    def commit_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        commit_id: builtins.str = ...,
        url: builtins.str = ...,
        message: builtins.str = ...,
        author: global___User | None = ...,
        impact_analysis: prodvana.proto.prodvana.impact_analysis.impact_analysis_pb2.ImpactAnalysisResult | None = ...,
        commit_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author", "commit_timestamp", b"commit_timestamp", "impact_analysis", b"impact_analysis"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "commit_id", b"commit_id", "commit_timestamp", b"commit_timestamp", "impact_analysis", b"impact_analysis", "message", b"message", "url", b"url"]) -> None: ...

global___Commit = Commit

class FuzzyCommit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMIT_ISH_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    commit_ish: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        commit_ish: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit_ish", b"commit_ish", "source", b"source"]) -> None: ...

global___FuzzyCommit = FuzzyCommit
